@@ -20,7 +20,7 @@ QT_BEGIN_NAMESPACE
 
 /*!
     \qmltype MapPolygon
-    \instantiates QDeclarativePolygonMapItem
+    \nativetype QDeclarativePolygonMapItem
     \inqmlmodule QtLocation
     \ingroup qml-QtLocation5-maps
     \since QtLocation 5.5
@@ -390,7 +390,7 @@ QDeclarativePolygonMapItem::QDeclarativePolygonMapItem(QQuickItem *parent)
     QObject::connect(&m_border, &QDeclarativeMapLineProperties::widthChanged,
                      this, &QDeclarativePolygonMapItem::onLinePropertiesChanged);
     QObject::connect(this, &QDeclarativePolygonMapItem::referenceSurfaceChanged,
-                     [=]() {m_d->onGeoGeometryChanged();});
+                     this, [this]() { m_d->onGeoGeometryChanged(); });
 }
 
 QDeclarativePolygonMapItem::~QDeclarativePolygonMapItem()
